@@ -135,8 +135,10 @@ def test_machine_from_config(default_globals: dict):
             "asset": "global-asset",
             "data_provider": {
                 "dl_service_auth_str": None,
-                "interactive": False,
-                "storename": "dataplatformdlsprod",
+                "storage": None,
+                "assets_config": None,
+                "interactive": None,
+                "storename": None,
                 "type": "DataLakeProvider",
             },
             "default_asset": None,
@@ -150,6 +152,7 @@ def test_machine_from_config(default_globals: dict):
             "resolution": "10T",
             "row_filter": "",
             "row_filter_buffer_size": 0,
+            "tag_normalizer": "default",
             "tag_list": [
                 "GRA-TE  -23-0733.PV",
                 "GRA-TT  -23-0719.PV",
